@@ -1,5 +1,5 @@
 #  Pyrogram - Telegram MTProto API Client Library for Python
-#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
+#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
 #
 #  This file is part of Pyrogram.
 #
@@ -19,7 +19,7 @@
 from typing import Optional, List
 
 import pyrogram
-from pyrogram import raw, types, utils
+from pyrogram import raw, types, utils, enums
 from .inline_query_result import InlineQueryResult
 
 
@@ -35,10 +35,23 @@ class InlineQueryResultAnimation(InlineQueryResult):
             A valid URL for the animated GIF file.
             File size must not exceed 1 MB.
 
+        animation_width (``int``, *optional*)
+            Width of the animation.
+
+        animation_height (``int``, *optional*)
+            Height of the animation.
+
+        animation_duration (``int``, *optional*)
+            Duration of the animation in seconds.
+
         thumb_url (``str``, *optional*):
             URL of the static thumbnail for the result (jpeg or gif)
             Defaults to the value passed in *animation_url*.
 
+        thumb_mime_type (``str``, *optional*)
+            MIME type of the thumbnail, must be one of "image/jpeg", "image/gif", or "video/mp4".
+            Defaults to "image/jpeg".
+
         id (``str``, *optional*):
             Unique identifier for this result, 1-64 bytes.
             Defaults to a randomly generated UUID4.
@@ -46,18 +59,12 @@ class InlineQueryResultAnimation(InlineQueryResult):
         title (``str``, *optional*):
             Title for the result.
 
-        description (``str``, *optional*):
-            Short description of the result.
-
         caption (``str``, *optional*):
-            Caption of the photo to be sent, 0-1024 characters.
+            Caption of the animation to be sent, 0-4096 characters.
 
-        parse_mode (``str``, *optional*):
+        parse_mode (:obj:`~pyrogram.enums.ParseMode`, *optional*):
             By default, texts are parsed using both Markdown and HTML styles.
             You can combine both syntaxes together.
-            Pass "markdown" or "md" to enable Markdown-style parsing only.
-            Pass "html" to enable HTML-style parsing only.
-            Pass None to completely disable style parsing.
 
         caption_entities (List of :obj:`~pyrogram.types.MessageEntity`):
             List of special entities that appear in the caption, which can be specified instead of *parse_mode*.
@@ -72,12 +79,16 @@ class InlineQueryResultAnimation(InlineQueryResult):
     def __init__(
         self,
         animation_url: str,
+        animation_width: int = 0,
+        animation_height: int = 0,
+        animation_duration: int = 0,
         thumb_url: str = None,
+        thumb_mime_type: str = "image/jpeg",
         id: str = None,
         title: str = None,
         description: str = None,
         caption: str = "",
-        parse_mode: Optional[str] = object,
+        parse_mode: Optional["enums.ParseMode"] = None,
         caption_entities: List["types.MessageEntity"] = None,
         reply_markup: "types.InlineKeyboardMarkup" = None,
         input_message_content: "types.InputMessageContent" = None
@@ -85,7 +96,11 @@ class InlineQueryResultAnimation(InlineQueryResult):
         super().__init__("gif", id, input_message_content, reply_markup)
 
         self.animation_url = animation_url
+        self.animation_width = animation_width
+        self.animation_height = animation_height
+        self.animation_duration = animation_duration
         self.thumb_url = thumb_url
+        self.thumb_mime_type = thumb_mime_type
         self.title = title
         self.description = description
         self.caption = caption
@@ -99,7 +114,13 @@ class InlineQueryResultAnimation(InlineQueryResult):
             url=self.animation_url,
             size=0,
             mime_type="image/gif",
-            attributes=[]
+            attributes=[
+                raw.types.DocumentAttributeVideo(
+                    w=self.animation_width,
+                    h=self.animation_height,
+                    duration=self.animation_duration
+                )
+            ]
         )
 
         if self.thumb_url is None:
@@ -108,7 +129,7 @@ class InlineQueryResultAnimation(InlineQueryResult):
             thumb = raw.types.InputWebDocument(
                 url=self.thumb_url,
                 size=0,
-                mime_type="image/gif",
+                mime_type=self.thumb_mime_type,
                 attributes=[]
             )
 
@@ -120,7 +141,6 @@ class InlineQueryResultAnimation(InlineQueryResult):
             id=self.id,
             type=self.type,
             title=self.title,
-            description=self.description,
             thumb=thumb,
             content=animation,
             send_message=(
